@@ -1,5 +1,6 @@
-from datetime import date, datetime, time
+import datetime
 import random
+import time
 
 import gtk
 
@@ -8,14 +9,14 @@ from kiwi.ui.widgets.list import (Column, List, SequentialColumn,
                                   ColoredColumn, SummaryLabel)
 
 def random_date():
-    max = datetime.today()
+    max = datetime.datetime.today()
     min = max.replace(year=max.year-5)
-    timestamp = random.randint(int(min.strftime('%s')),
-                               int(max.strftime('%s')))
-    if timestamp % 2 == 0:
-        return 
-    return datetime.fromtimestamp(timestamp)
-    
+
+    timestamp = random.randint(
+        time.mktime(min.timetuple()),
+        time.mktime(max.timetuple()))
+    return datetime.datetime.fromtimestamp(timestamp)
+
 class Person:
     """The parameters need to be of the same name of the column headers"""
     def __init__(self, name, age, city):
@@ -25,7 +26,7 @@ class Person:
         self.extra = -1
         self.worth = random.randint(0, 10000) / 100.0
         self.bool = random.randint(0, 1) and True or False
-        
+
     def __repr__(self):
         return '<Person %s>' % self._name
 
@@ -48,9 +49,9 @@ columns = [
     Column('bool', data_type=bool, editable=True, width=40),
     Column('worth', data_type=currency, editable=True),
     Column('city', visible=True, sorted=True),
-    Column('date', data_type=date),
-    Column('time', data_type=time),
-    Column('datetime', data_type=datetime),
+    Column('date', data_type=datetime.date),
+    Column('time', data_type=datetime.time),
+    Column('datetime', data_type=datetime.datetime),
     ColoredColumn('age', data_type=int, color='red', data_func=color),
     ]
 
@@ -58,7 +59,7 @@ data = (Person('Evandro', 23, 'Belo Horizonte'),
         Person('Daniel', 22, 'Sao Carlos'),
         Person('Henrique', 21, 'Sao Carlos'),
         Person('Gustavo', 23, 'San Jose do Santos'),
-        Person('Johan', 23, 'Goteborg'), 
+        Person('Johan', 23, 'Goteborg'),
         Person('Lorenzo', 26, 'Granada')
        )
 
