@@ -1,7 +1,7 @@
 #
 # Kiwi: a Framework and Enhanced Widgets for Python
 #
-# Copyright (C) 2005 Async Open Source
+# Copyright (C) 2005,2006 Async Open Source
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -26,9 +26,10 @@ Argument checking decorator and support
 """
 
 import inspect
+from types import ClassType
 
 class CustomType(type):
-    def value_check(cls, name, value):
+    def value_check(mcs, name, value):
         pass
     value_check = classmethod(value_check) 
 
@@ -43,11 +44,13 @@ class percent(CustomType):
     Custom type that verifies that the value is a percentage
     """
     type = int, float
-    def value_check(cls, name, value):
+    def value_check(mcs, name, value):
         if 0 > value < 100:
             raise ValueError("%s must be between 0 and 100" % name)
     value_check = classmethod(value_check) 
-       
+
+_NoValue = object()
+
 class argcheck(object):
     """
     Decorator to check type and value of arguments.
@@ -72,8 +75,8 @@ class argcheck(object):
     
     def __init__(self, *types):
         for argtype in types:
-            if not isinstance(argtype, type):
-                raise TypeError("must be a type instance")
+            if not isinstance(argtype, (type, ClassType)):
+                raise TypeError("must be a type or class instance")
         self.types = types
 
     def enable(cls):
@@ -94,14 +97,27 @@ class argcheck(object):
         if not callable(func):
             raise TypeError("%r must be callable" % func)
 
+        # Useful for optimized runs
+        if not self.__enabled__:
+            return func
+        
         spec = inspect.getargspec(func)
         arg_names, is_varargs, is_kwargs, default_values = spec
-        
+        if not default_values:
+            default_values = []
+        else:
+            default_values = list(default_values)
+
+        # Set all the remaining default values to _NoValue
+        default_values = ([_NoValue] * (len(arg_names) - len(default_values)) +
+                          default_values)
+
         # TODO: Is there another way of doing this?
         #       Not trivial since func is not attached to the class at
         #       this point. Nor is the class attached to the namespace.
         if arg_names and arg_names[0] in ('self', 'cls'):
             arg_names = arg_names[1:]
+            default_values = default_values[1:]
             is_method = True
         else:
             is_method = False
@@ -118,37 +134,40 @@ class argcheck(object):
                                  len(types),
                                  len(arg_names)))
 
-        defs = len(default_values or ())
         kwarg_types = {}
+        kwarg_defaults = {}
+
         for i, arg_name in enumerate(arg_names):
             kwarg_types[arg_name] = types[i]
+            value = default_values[i]
+            kwarg_defaults[arg_name] = value
+            if value is None or value is _NoValue:
+                continue
+            arg_type = types[i]
+            try:
+                self._type_check(value, arg_type, arg_name)
+            except TypeError:
+                raise TypeError("default value for %s must be of type %s "
+                                "and not %s" % (arg_name,
+                                                arg_type.__name__,
+                                                type(value).__name__))
+            kwarg_defaults[arg_name] = value
             
-            pos = defs - i
-            if defs and 0 < pos < defs:
-                value = default_values[pos]
-                if value is None:
-                    continue
-                arg_type = types[pos]
-                try:
-                    self._type_check(value, arg_type, arg_name)
-                except TypeError:
-                    raise TypeError("default value for %s must be of type %s "
-                                    "and not %s" % (arg_name,
-                                                    arg_type.__name__,
-                                                    type(value).__name__))
         def wrapper(*args, **kwargs):
             if self.__enabled__:
                 cargs = args
                 if is_method:
                     cargs = cargs[1:]
-                
-                # Positional arguments
-                for arg, type, name in zip(cargs, types, arg_names):
-                    self._type_check(arg, type, name)
 
+                # Positional arguments
+                for arg, type, name, default in zip(cargs, types, arg_names,
+                                                    default_values):
+                    self._type_check(arg, type, name, default)
+                    
                 # Keyword arguments
                 for name, arg in kwargs.items():
-                    self._type_check(arg, kwarg_types[name], name)
+                    self._type_check(arg, kwarg_types[name], name,
+                                     kwarg_defaults[name])
 
                 self.extra_check(arg_names, types, args, kwargs)
             return func(*args, **kwargs)
@@ -158,7 +177,10 @@ class argcheck(object):
     def extra_check(self, names, types, args, kwargs):
         pass
 
-    def _type_check(self, value, argument_type, name):
+    def _type_check(self, value, argument_type, name, default=_NoValue):
+        if default is not _NoValue and value == default:
+            return
+        
         if issubclass(argument_type, CustomType):
             custom = True
             check_type = argument_type.type
