@@ -29,42 +29,46 @@
 import gtk
 
 from kiwi import ValueUnset
-from kiwi.interfaces import implementsIProxy
-from kiwi.utils import gsignal, gproperty, type_register
+from kiwi.utils import PropertyObject, gsignal, gproperty
 from kiwi.ui.widgets.proxy import WidgetMixin
 
-class RadioButton(gtk.RadioButton, WidgetMixin):
-    implementsIProxy()
+class RadioButton(PropertyObject, gtk.RadioButton, WidgetMixin):
     gproperty('data-value', str, nick='Data Value')
 
     def __init__(self):
-        WidgetMixin.__init__(self)
         gtk.RadioButton.__init__(self)
-        self._data_value = None
-        self.show()
+        WidgetMixin.__init__(self)
+        PropertyObject.__init__(self)
     
     gsignal('toggled', 'override')
     def do_toggled(self):
         self.emit('content-changed')
         self.chain()
 
-    def read(self):
-        for rb in self.get_group():
-            if rb.get_active():
-                return self.str2type(rb.get_property('data-value'))
+    def get_selected(self):
+        """
+        Get the currently selected radiobutton.
+        
+        @returns: The selected L{RadioButton} or None if there are no
+          selected radiobuttons.
+        """
+        
+        for button in self.get_group():
+            if button.get_active():
+                return button
 
+    def read(self):
+        button = self.get_selected()
+        if button is None:
+            return ValueUnset
+        
+        return self._from_string(button.data_value)
+    
     def update(self, data):
-        if data is None or data is ValueUnset:
+        if data is None:
             return
-        data = self.type2str(data)
+        
+        data = self._as_string(data)
         for rb in self.get_group():
             if rb.get_property('data-value') == data:
                 rb.set_active(True)
-    
-    def prop_set_data_value(self, data):
-        self._data_value = data
-    
-    def prop_get_data_value(self):
-        return self._data_value
-
-type_register(RadioButton)
