@@ -32,35 +32,27 @@ L{kiwi.ui.icon.IconEntry}
 
 import gtk
 
-from kiwi import ValueUnset
-from kiwi.interfaces import implementsIProxy, implementsIMandatoryProxy
 from kiwi.ui.icon import IconEntry
 from kiwi.ui.widgets.proxy import WidgetMixinSupportValidation
-from kiwi.utils import gsignal, type_register
+from kiwi.utils import PropertyObject, gsignal
 
-class SpinButton(gtk.SpinButton, WidgetMixinSupportValidation):
-    implementsIProxy()
-    implementsIMandatoryProxy()
+class SpinButton(PropertyObject, gtk.SpinButton, WidgetMixinSupportValidation):
+    """
+    A SpinButton subclass which adds supports for the Kiwi Framework.
+    This widget supports validation
+    The only allowed types for spinbutton are int and float.
 
+    """
+    allowed_data_types = int, float
+    
     def __init__(self):
         # since the default data_type is str we need to set it to int 
         # or float for spinbuttons
         gtk.SpinButton.__init__(self)
-        WidgetMixinSupportValidation.__init__(self, data_type=int)
+        PropertyObject.__init__(self, data_type=int)
+        WidgetMixinSupportValidation.__init__(self)
         self._icon = IconEntry(self)
-        self.show()
         
-    def prop_set_data_type(self, data_type):
-        """Overriden from super class. Since spinbuttons should
-        only accept float or int numbers we need to make a special
-        treatment.
-        """
-        old_datatype = self._data_type
-        WidgetMixinSupportValidation.prop_set_data_type(self, data_type)
-        if self._data_type not in (int, float):
-            self._data_type = old_datatype
-            raise TypeError("SpinButtons only accept integer or float values")
-
     # GtkEditable.changed is called too often
     # GtkSpinButton.value-changed is called only when the value changes
     gsignal('value-changed', 'override')
@@ -69,12 +61,14 @@ class SpinButton(gtk.SpinButton, WidgetMixinSupportValidation):
         self.chain()
 
     def read(self):
-        return self.get_text()
+        return self._from_string(self.get_text())
     
     def update(self, data):
-        if data is ValueUnset or data is None:
+        if data is None:
             self.set_text("")
         else:
+            # set_value accepts a float or int, no as_string conversion needed,
+            # and since we accept only int and float just send it in.
             self.set_value(data)
 
     def do_expose_event(self, event):
@@ -110,5 +104,3 @@ class SpinButton(gtk.SpinButton, WidgetMixinSupportValidation):
 
     def get_icon_window(self):
         return self._icon.get_icon_window()
-
-type_register(SpinButton)
